@echo off

title Correcting device driver setups for older device driver versions...

:: cmd.exe does not support UNC paths, see Microsoft knowledge base Q156276.
:: If the batch file is started from a network path
:: the current directory defaults to the Windows directory. 
:: If this is the case, we abort this batch file here.
:: %cd% returns the current directory
if #"%cd%"#==#"%windir%"# goto ERROR_UNC

echo Correcting device driver setups for older device driver versions...
echo.
echo This patch can be executed with any installed DIGSI 4 version.
echo It fixes an issue with some device driver setups without changing the device
echo drivers itself. All DIGSI 4 projects remain working and are unchanged.
echo. 
echo There is no risk running this patch multiple times.
echo ------
pause

:: check if DIGSI4 is installed
REG QUERY "HKLM\SOFTWARE\Siemens\DIGSI4\USERINFO" >nul
if errorlevel 1 (
	echo Error reading HKLM\SOFTWARE\Siemens\DIGSI4\USERINFO
	echo Please check your DIGSI 4 installation. 
	echo This patch only needs to be executed on machines where DIGSI 4 is installed.
	pause
	goto ERROR_REGISTRY_ERROR
)

:: detect DIGSI 4 version
:: delims is a TAB followed by a space
FOR /F "tokens=2* delims=	 " %%A IN ('REG QUERY "HKLM\SOFTWARE\Siemens\DIGSI4\USERINFO" /v VERSION') DO SET DIGVER=%%B
SET SHORTVER=%DIGVER:~0,3%

if %SHORTVER% == 4.8 (
	goto CONTINUE1
) else (
	echo Everything is fine. The installed DIGSI V %DIGVER:~0,4% does not need corrections.
	pause
	goto END1
)

:CONTINUE1

:: detect DIGSI4 installation directory (the path of Digsi4.exe)
:: default is C:\Siemens\Digsi4\
:: delims is a TAB followed by a space
FOR /F "tokens=2* delims=	 " %%A IN ('REG QUERY "HKLM\SOFTWARE\Siemens\DIGSI4\PROGRAMME" /v Digsi') DO SET DigsiPath=%%B
if #"%DigsiPath%"#==#""# goto ERROR_NO_DIGSIPATH

set File=%DigsiPath%DevUinst.dll

if exist "%File%" goto FIXIT

echo Everything is fine. No device driver setups need corrections.
pause
goto END1

:FIXIT

REG DELETE "HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\DIGSI 4 Dev" /f
if errorlevel 1 (
	echo Cannot delete "HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\DIGSI 4 Dev"
	echo Please check your user rights and try again as administrator.
	echo You need administrator rights to run this Patch successfully.
	pause
	goto ERROR_REGISTRY_ERROR
)

del "%DigsiPath%DevUinst.dll"

echo Setups of older device drivers corrected. Please DO NOT use the DIGSI drivers 
echo that have been provided for DIGSI 4.21, 4.30, 4.40 in the SIPROTEC download
echo area. Please use the drivers provided with DIGSI 4.83 instead; they install
echo as well for older DIGSI versions.
pause
goto END1

:ERROR_UNC
echo ------
echo This batch file can not run from an UNC network share. Please copy this 
echo batch file into a directory on your local PC or assign a drive letter to the
echo network drive via "net use" and start from there.
goto END1

:ERROR_NO_DIGSIPATH
echo ------
echo Could not read DIGSI 4 path from the registry. 
echo Please check your DIGSI 4 installation. 
echo This patch only needs to be executed on machines where DIGSI 4 is installed.
goto END1

:ERROR_REGISTRY_ERROR
echo Registry access failed.
goto END1


:END1

echo ------
echo End of 'Correcting device driver setups for older device driver versions'
echo ------
pause

